@@ -1,6 +1,7 @@
 import time
 from collections import defaultdict
 
+import gc
 import logging
 import multiprocessing
 
@@ -68,6 +69,9 @@ class MirrorScheduler:
         self.previous_scopefilter_excluded = None
 
     def run(self) -> None:
+        if get_setting('database_readonly'):
+            return
+
         if get_setting('rpki.roa_source'):
             import_timer = int(get_setting('rpki.roa_import_timer'))
             self.run_if_relevant(RPKI_IRR_PSEUDO_SOURCE, ROAImportRunner, import_timer)
@@ -88,7 +92,7 @@ class MirrorScheduler:
             if is_mirror:
                 started_import = self.run_if_relevant(source, RPSLMirrorImportUpdateRunner, import_timer)
 
-            runs_export = get_setting(f'sources.{source}.export_destination')
+            runs_export = get_setting(f'sources.{source}.export_destination') or get_setting(f'sources.{source}.export_destination_unfiltered')
             export_timer = int(get_setting(f'sources.{source}.export_timer', DEFAULT_SOURCE_EXPORT_TIMER))
 
             if runs_export:
@@ -151,6 +155,7 @@ class MirrorScheduler:
 
     def update_process_state(self):
         multiprocessing.active_children()  # to reap zombies
+        gc_collect_needed = False
         for process_name, process in list(self.processes.items()):
             if process.is_alive():
                 continue
@@ -160,3 +165,7 @@ class MirrorScheduler:
                 logging.error(f'Failed to close {process_name} (pid {process.pid}), '
                               f'possible resource leak: {e}')
             del self.processes[process_name]
+            gc_collect_needed = True
+        if gc_collect_needed:
+            # prevents FIFO pipe leak, see #578
+            gc.collect()
