@@ -8,13 +8,13 @@ import argparse
 import sys
 
 from pathlib import Path
-from typing import Set
+from typing import Optional, Set
 
 from irrd.storage.models import JournalEntryOrigin
 
 sys.path.append(str(Path(__file__).resolve().parents[2]))
 
-from irrd.conf import CONFIG_PATH_DEFAULT, config_init
+from irrd.conf import CONFIG_PATH_DEFAULT, config_init, get_setting
 from irrd.storage.database_handler import DatabaseHandler
 from irrd.rpsl.parser import UnknownRPSLObjectClassException
 from irrd.rpsl.rpsl_objects import rpsl_object_from_text
@@ -26,7 +26,7 @@ class RPSLParse:
     obj_errors = 0
     obj_unknown = 0
     unknown_object_classes: Set[str] = set()
-    database_handler = None
+    database_handler: Optional[DatabaseHandler] = None
 
     def main(self, filename, strict_validation, database, show_info=True):
         self.show_info = show_info
@@ -96,6 +96,10 @@ def main():  # pragma: no cover
     args = parser.parse_args()
 
     config_init(args.config_file_path)
+    if get_setting('database_readonly'):
+        print('Unable to run, because database_readonly is set')
+        sys.exit(-1)
+        
     RPSLParse().main(args.input_file, args.strict_validation, args.database, not args.hide_info)
 
 
