@@ -23,8 +23,8 @@ from irrd.updates.handler import ChangeSubmissionHandler
 
 
 def main(data):
-    handler = ChangeSubmissionHandler(data)
-    print(handler.submitter_report())
+    handler = ChangeSubmissionHandler().load_text_blob(data)
+    print(handler.submitter_report_human())
 
 
 if __name__ == '__main__':  # pragma: no cover
