@@ -6,7 +6,7 @@ from irrd.conf import get_setting
 logger = logging.getLogger(__name__)
 
 
-def is_client_permitted(ip: str, access_list_setting: str, default_deny=True) -> bool:
+def is_client_permitted(ip: str, access_list_setting: str, default_deny=True, log=True) -> bool:
     """
     Determine whether a client is permitted to access an interface,
     based on the value of the setting of access_list_setting.
@@ -17,8 +17,9 @@ def is_client_permitted(ip: str, access_list_setting: str, default_deny=True) ->
     try:
         client_ip = IP(ip)
     except (ValueError, AttributeError) as e:
-        logger.error(f'Rejecting request as client IP could not be read from '
-                     f'{ip}: {e}')
+        if log:
+            logger.error(f'Rejecting request as client IP could not be read from '
+                         f'{ip}: {e}')
         return False
 
     if client_ip.version() == 6:
@@ -32,12 +33,13 @@ def is_client_permitted(ip: str, access_list_setting: str, default_deny=True) ->
 
     if not access_list_name or not access_list:
         if default_deny:
-            logger.info(f'Rejecting request, access list empty or undefined: {client_ip}')
+            if log:
+                logger.info(f'Rejecting request, access list empty or undefined: {client_ip}')
             return False
         else:
             return True
 
     allowed = any([client_ip in IP(allowed) for allowed in access_list])
-    if not allowed:
+    if not allowed and log:
         logger.info(f'Rejecting request, IP not in access list {access_list_name}: {client_ip}')
     return allowed
