@@ -4,7 +4,9 @@ from typing import List, Optional
 import sqlalchemy as sa
 from IPy import IP
 from sqlalchemy.sql import Select, ColumnCollection
+import sqlalchemy.dialects.postgresql as pg
 
+from irrd.conf import get_setting
 from irrd.rpki.status import RPKIStatus
 from irrd.rpsl.rpsl_objects import lookup_field_names
 from irrd.scopefilter.status import ScopeFilterStatus
@@ -25,13 +27,18 @@ class BaseRPSLObjectDatabaseQuery:
         self._sources_list = []
         self._ordered_by_sources = ordered_by_sources
         self._enable_ordering = enable_ordering
+        self._set_object_classes = []
 
     def pk(self, pk: str):
         """Filter on an exact object PK (UUID)."""
         return self._filter(self.columns.pk == pk)
 
+    def pks(self, pks: List[str]):
+        """Filter on exact object PKs (UUID)."""
+        return self._filter(self.columns.pk.in_(pks))
+
     def rpsl_pk(self, rpsl_pk: str):
-        """Filter on an exact RPSL PK (e.g. 192.0.2.0/24,AS65537)."""
+        """Filter on an exact RPSL PK (e.g. 192.0.2.0/24AS65537)."""
         return self.rpsl_pks([rpsl_pk])
 
     def rpsl_pks(self, rpsl_pks: List[str]):
@@ -58,12 +65,17 @@ class BaseRPSLObjectDatabaseQuery:
         Classes list must be an iterable. Will match objects from any
         of the mentioned classes.
         """
+        self._set_object_classes = object_classes
         fltr = self.columns.object_class.in_(object_classes)
         return self._filter(fltr)
 
     def first_only(self):
         """Only return the first match."""
-        self.statement = self.statement.limit(1)
+        return self.limit(1)
+
+    def limit(self, record_limit: int):
+        """Limit the response to a certain number of rows"""
+        self.statement = self.statement.limit(record_limit)
         return self
 
     def finalise_statement(self) -> Select:
@@ -133,6 +145,12 @@ class RPSLDatabaseQuery(BaseRPSLObjectDatabaseQuery):
                 self.columns.object_text,
                 self.columns.source,
                 self.columns.rpki_status,
+                self.columns.updated,
+                self.columns.asn_first,
+                self.columns.asn_last,
+                self.columns.ip_first,
+                self.columns.ip_last,
+                self.columns.prefix_length,
             ]
         else:
             columns = [self.columns.get(name) for name in column_names]
@@ -189,11 +207,15 @@ class RPSLDatabaseQuery(BaseRPSLObjectDatabaseQuery):
 
     def ip_less_specific(self, ip: IP):
         """Filter any less specifics or exact matches of a prefix."""
-        fltr = sa.and_(
-            self.columns.ip_first <= str(ip.net()),
-            self.columns.ip_last >= str(ip.broadcast()),
-            self.columns.ip_version == ip.version()
-        )
+        if self._prefix_query_permitted():
+            pg_prefix = sa.cast(str(ip), pg.CIDR)
+            fltr = self.columns.prefix.op(">>=")(pg_prefix)
+        else:
+            fltr = sa.and_(
+                self.columns.ip_first <= str(ip.net()),
+                self.columns.ip_last >= str(ip.broadcast()),
+                self.columns.ip_version == ip.version()
+            )
         return self._filter(fltr)
 
     def ip_less_specific_one_level(self, ip: IP):
@@ -230,14 +252,49 @@ class RPSLDatabaseQuery(BaseRPSLObjectDatabaseQuery):
         Note that this only finds full more specifics: objects for which their
         IP range is fully encompassed by the ip parameter.
         """
-        fltr = sa.and_(
-            self.columns.ip_first >= str(ip.net()),
-            self.columns.ip_first <= str(ip.broadcast()),
-            self.columns.ip_last <= str(ip.broadcast()),
-            self.columns.ip_last >= str(ip.net()),
-            self.columns.ip_version == ip.version(),
-            sa.not_(sa.and_(self.columns.ip_first == str(ip.net()), self.columns.ip_last == str(ip.broadcast()))),
-        )
+        if self._prefix_query_permitted():
+            pg_prefix = sa.cast(str(ip), pg.CIDR)
+            fltr = self.columns.prefix.op("<<")(pg_prefix)
+        else:
+            fltr = sa.and_(
+                self.columns.ip_first >= str(ip.net()),
+                self.columns.ip_first <= str(ip.broadcast()),
+                self.columns.ip_last <= str(ip.broadcast()),
+                self.columns.ip_last >= str(ip.net()),
+                self.columns.ip_version == ip.version(),
+                sa.not_(sa.and_(self.columns.ip_first == str(ip.net()), self.columns.ip_last == str(ip.broadcast()))),
+            )
+        return self._filter(fltr)
+
+    def ip_any(self, ip: IP):
+        """
+        Filter any less specifics, more specifics or exact matches of a prefix.
+
+        Note that this only finds full more specifics: objects for which their
+        IP range is fully encompassed by the ip parameter - not partial overlaps.
+        """
+        if self._prefix_query_permitted():
+            pg_prefix = sa.cast(str(ip), pg.CIDR)
+            fltr = sa.or_(
+                self.columns.prefix.op(">>=")(pg_prefix),
+                self.columns.prefix.op("<<")(pg_prefix),
+            )
+        else:
+            fltr = sa.and_(
+                sa.or_(
+                    sa.and_(
+                        self.columns.ip_first <= str(ip.net()),
+                        self.columns.ip_last >= str(ip.broadcast()),
+                    ),
+                    sa.and_(
+                        self.columns.ip_first >= str(ip.net()),
+                        self.columns.ip_first <= str(ip.broadcast()),
+                        self.columns.ip_last <= str(ip.broadcast()),
+                        self.columns.ip_last >= str(ip.net()),
+                    ),
+                ),
+                self.columns.ip_version == ip.version()
+            )
         return self._filter(fltr)
 
     def asn(self, asn: int):
@@ -279,7 +336,7 @@ class RPSLDatabaseQuery(BaseRPSLObjectDatabaseQuery):
         fltr = self.columns.scopefilter_status.in_(status)
         return self._filter(fltr)
 
-    def text_search(self, value: str):
+    def text_search(self, value: str, extract_asn_ip=True):
         """
         Search the database for a specific free text.
 
@@ -291,19 +348,21 @@ class RPSLDatabaseQuery(BaseRPSLObjectDatabaseQuery):
         - Otherwise, return all objects where the RPSL primary key is exactly this value,
           or it matches part of a person/role name (not nic-hdl, their
           actual person/role attribute value).
+         If extract_asn_ip is False, the first two steps are skipped.
         """
         self._check_query_frozen()
-        try:
-            _, asn = parse_as_number(value)
-            return self.object_classes(['as-block', 'as-set', 'aut-num']).asn_less_specific(asn)
-        except ValidationError:
-            pass
+        if extract_asn_ip:
+            try:
+                _, asn = parse_as_number(value)
+                return self.object_classes(['as-block', 'as-set', 'aut-num']).asn_less_specific(asn)
+            except ValidationError:
+                pass
 
-        try:
-            ip = IP(value)
-            return self.ip_less_specific(ip)
-        except ValueError:
-            pass
+            try:
+                ip = IP(value)
+                return self.ip_less_specific(ip)
+            except ValueError:
+                pass
 
         counter = self._lookup_attr_counter
         self._lookup_attr_counter += 1
@@ -323,8 +382,14 @@ class RPSLDatabaseQuery(BaseRPSLObjectDatabaseQuery):
         )
         return self
 
+    def _prefix_query_permitted(self):
+        return (
+            get_setting('compatibility.inetnum_search_disabled')
+            or (self._set_object_classes and 'inetnum' not in self._set_object_classes)
+        ) and not get_setting('compatibility.irrd42_migration_in_progress')
+
     def __repr__(self):
-        return f'RPSLDatabaseQuery: {self.statement}\nPARAMS: {self.statement.compile().params}'
+        return f'{self.statement}\nPARAMS: {self.statement.compile().params}'
 
 
 class RPSLDatabaseJournalQuery(BaseRPSLObjectDatabaseQuery):
@@ -345,6 +410,7 @@ class RPSLDatabaseJournalQuery(BaseRPSLObjectDatabaseQuery):
             self.columns.operation,
             self.columns.object_class,
             self.columns.object_text,
+            self.columns.origin,
             self.columns.timestamp,
         ]).order_by(self.columns.source.asc(), self.columns.serial_nrtm.asc())
 
